@@ -28,14 +28,14 @@ class SettingsProperty(webdav.Property):
     JSON settings.
     """
 
-    name = '{http://inf-it.com/ns/dav/}settings'
+    name = "{http://inf-it.com/ns/dav/}settings"
     resource_type = webdav.PRINCIPAL_RESOURCE_TYPE
     live = False
 
-    def get_value(self, href, resource, el, environ):
+    async def get_value(self, href: str, resource, el, environ):
         el.text = resource.get_infit_settings()
 
-    def set_value(self, href, resource, el):
+    def set_value(self, href: str, resource, el):
         resource.set_infit_settings(el.text)
 
 
@@ -45,11 +45,11 @@ class AddressbookColorProperty(webdav.Property):
     Contains a RRGGBB code, similar to calendar-color.
     """
 
-    name = '{http://inf-it.com/ns/ab/}addressbook-color'
+    name = "{http://inf-it.com/ns/ab/}addressbook-color"
     resource_type = carddav.ADDRESSBOOK_RESOURCE_TYPE
     in_allprops = False
 
-    def get_value(self, href, resource, el, environ):
+    async def get_value(self, href, resource, el, environ):
         el.text = resource.get_addressbook_color()
 
     def set_value(self, href, resource, el):
@@ -62,12 +62,12 @@ class HeaderValueProperty(webdav.Property):
     This behaves similar to the hrefLabel setting in caldavzap/carddavmate.
     """
 
-    name = '{http://inf-it.com/ns/dav/}headervalue'
+    name = "{http://inf-it.com/ns/dav/}headervalue"
     resource_type = webdav.COLLECTION_RESOURCE_TYPE
     in_allprops = False
     live = False
 
-    def get_value(self, href, resource, el, environ):
+    async def get_value(self, href, resource, el, environ):
         el.text = resource.get_headervalue()
 
     def set_value(self, href, resource, el):
